@@ -4,7 +4,7 @@ import os, collections, datetime, shutil, tarfile
 from nesoni import io, config
 
 
-def mine_logs(filenames, filter=lambda sample, field: True):
+def mine_logs(filenames, filter=lambda sample, field: True, commas=False):
     samples = [ ]
     fields = [ ]
     data = { }
@@ -20,13 +20,15 @@ def mine_logs(filenames, filter=lambda sample, field: True):
                 samples.append(sample)
             if field not in fields:
                 fields.append(field)
-            data[ (sample,field) ] = value.replace(',','')
+            if not commas:
+                value = value.replace(',','')
+            data[ (sample,field) ] = value
         f.close()
     
     records = [ ]
     for field in fields:
         records.append(collections.OrderedDict(
-           [ ('Statistic', field) ] + [ (item, data.get((item,field),'')) for item in samples ]
+           [ ('', field) ] + [ (item, data.get((item,field),'')) for item in samples ]
         ))
     return records
 
@@ -68,6 +70,7 @@ body { font-family: sans-serif; margin-left: 5em; margin-right: 5em; }
 img { vertical-align: middle; }
 a { text-decoration: none; }
 h1,h2,h3,h4,h5,h6 { margin-top: 2em; }
+td,th { padding: 0.5em; }
 """
 
 class Reporter(object):
@@ -128,10 +131,11 @@ class Reporter(object):
             prefix = self.file_prefix
         dest = self.workspace / (prefix+name)
         
-        Copy(
-            dest = dest,
-            source = filename,
-        ).make()
+        #Copy(
+        #    dest = dest,
+        #    source = filename,
+        #    ).make()
+        io.symbolic_link(source=filename, link_name=dest)
         
         return self.href(dest, title, image)
     
@@ -153,10 +157,31 @@ class Reporter(object):
         
         return self.href(dest, title)
         
-    def report_logs(self, name, logs, filter=lambda sample, field: True):
-        filename = self.workspace / (self.file_prefix + name + '.csv')        
-        io.write_csv(filename, mine_logs(logs, filter))        
-        self.p(self.href(filename))
+    def report_logs(self, name, logs, filter=(lambda sample, field: True), renaming={}):
+        table = mine_logs(logs, filter)
+        
+        if name:
+            filename = self.workspace / (self.file_prefix + name + '.csv')        
+            io.write_csv(filename, table)
+            self.p(self.href(filename))
+        
+        if table:
+            table = mine_logs(logs, filter, commas=True)
+            
+            self.write('<table>\n')
+            self.write('<tr>\n')
+            for key in table[0].keys():
+                self.write('<th>'+key+'</th>')
+            self.write('</tr>\n')
+            for row in table:
+                self.write('<tr>\n')
+                for i,value in enumerate(row.values()):
+                    if i == 0:
+                        value = renaming.get(value,value)
+                    self.write('<td>'+value+'</td>')
+                self.write('</tr>\n')
+            self.write('</table>\n')
+                
         
     def report_heatmap(self, action, has_csv=True):
         self.p(
@@ -166,6 +191,10 @@ class Reporter(object):
     
     def report_test(self, action):
         self.p(
+            self.get(action.prefix + '-heatmap.png', image=True, title='[heatmap]') +
+            (' &sdot; ' + self.get(action.prefix+'.png', image=True,title='[MA-plot]')
+                if os.path.exists(action.prefix+'.png') else '') +
+            ' &sdot; ' +
             self.get(action.prefix + '.txt') +
             ' &sdot; ' +
             self.get(action.prefix+'-info.txt', title='[info]')
